@@ -10,6 +10,7 @@ seqtrate <- function(seqdata, statl=NULL) {
 	## State list if not specified
 	if (is.null(statl)) statl <- attr(seqdata,"alphabet")
 	nr <- attr(seqdata,"nr")
+	void <- attr(seqdata,"void")
 
 	nbetat <- length(statl)
 	tmat <- matrix(nrow=nbetat, ncol=nbetat)
@@ -26,12 +27,13 @@ seqtrate <- function(seqdata, statl=NULL) {
 		## Count
 		PA <- 0
 		for (sl in 1:(sdur-1))
-			PA <- PA + sum(seqdata[,sl]==statl[x] & seqdata[,sl+1]!=nr,na.rm=TRUE)
+			PA <- PA + sum(seqdata[,sl]==statl[x] 
+				& seqdata[,sl+1]!=nr & seqdata[,sl+1]!=void, na.rm=TRUE)
 		for (y in 1:nbetat) {
 			PAB <- 0
 			for (i in 1:sdur-1) {
 				PAB <- PAB + sum(seqdata[,i]==statl[x] & seqdata[,i+1]==statl[y],na.rm=TRUE)
-				}
+			}
 			if (PA==0) tmat[x,y] <- 0 else tmat[x,y] <- PAB/PA
 		}
 	}
